pub struct Connection { /* private fields */ }Expand description
A wrapper around an iroh::endpoint::Connection that implements the
h3::quic::Connection trait for use in HTTP/3 over QUIC.
This struct manages incoming and outgoing unidirectional and bidirectional
streams and handles conversions between iroh and h3 errors.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn new(conn: Connection) -> Self
pub fn new(conn: Connection) -> Self
Creates a new Connection from an existing iroh::endpoint::Connection.
This sets up async streams for accepting incoming unidirectional and bidirectional QUIC streams.
Arguments
conn- The underlyingirohconnection to wrap.